==> haskell-hls-qualify-imported-names-plugin-1.0.2.0-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-qualify-imported-names-plugin
version:              1.0.2.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-1.0.2.0-IckletZ947C6hFlzuR79iv

key:
    hls-qualify-imported-names-plugin-1.0.2.0-IckletZ947C6hFlzuR79iv

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1af0df0b942750bf132266a907a7f7cc
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-1.0.2.0-IckletZ947C6hFlzuR79iv

depends:
    aeson-2.1.2.1-I893iKJ0oHPJ1jEwOVWed6 base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    ghc-9.2.8 ghcide-1.10.0.0-ANlEi69wfG3LLHXTGtAddY
    hls-graph-1.9.0.0-JdUlZol8TlX5JgxZobn6H
    hls-plugin-api-1.6.0.0-1E7kwkfpka34t1TV7dkYk6
    lsp-1.6.0.0-Fm3bPcTc1xJ3BY9cZfhboY text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-HYi8F0R2X5DJGcgMLraHLn

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-qualify-imported-names-plugin-1.0.2.0-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-qualify-imported-names-plugin
version:              1.0.2.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-1.0.2.0-Gr92T9xBNCj6cYnSWRJMjo

key:
    hls-qualify-imported-names-plugin-1.0.2.0-Gr92T9xBNCj6cYnSWRJMjo

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  55dd6ead0fe44345c334f784e17c95b2
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-1.0.2.0-Gr92T9xBNCj6cYnSWRJMjo

depends:
    aeson-2.1.2.1-F8qbdML4nHt6X1eCfIdgPU base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    ghc-9.2.8 ghcide-1.10.0.0-IyZJU9ShAsOLHz3z86kaox
    hls-graph-1.9.0.0-9RRWqPqIxZzFwMxWPRLMiR
    hls-plugin-api-1.6.0.0-Bw07DIxkPHcE0QKpWMSn6u
    lsp-1.6.0.0-Kbn6gRXsz0E5q6RcN1gzkU text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
